**************
Example Models
**************


Here's an overview of some of the different modes of operation and models for TARDIS

.. toctree::
    :maxdepth: 1

    profileexp

    profilepl

    profileuniform

    profilemodel


.. note:: 

   Increasing the number of virtual packets will improve the
   signal-to-noise of TARDIS spectra. You may wish to consider using a
   filter (e.g. Savitzky–Golay) to suppress the Monte Carlo noise for
   some applications.

.. warning::

   The usefulness of any TARDIS calculations depends on the
   quality of the input atomic data. For further information on the atomic data -
   including details of how to develop your own dataset to suit your
   needs - please contact us.
